@@ -304,7 +304,7 @@ class BaseExperiment:
             >>> exp.set_model(LitModel)
 
         """
-        if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type): # astrape models
+        if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type) or SegNet in inspect.getmro(model_type): # astrape models
             self.model = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
             self.model_metadata = self.set_model_metadata(self.model, self.model.hparams)
         elif pl.LightningModule in inspect.getmro(model_type): # other pl.LightningModules not defined in astrape
