@@ -604,7 +604,6 @@ class BaseProject:
                 dims = rearrange_dims(dims=self.dims, in_format=dataformats, dataformats="NCHW")
                 imgs = np.reshape(self.X, (-1, *dims)) # (# of samples, # of channels, height, width) i.e., NCHW
 
-
             sampling_idx = np.random.choice(range(imgs.shape[0]), size=n_data)
             imgs_to_show = imgs[sampling_idx]
             labels_to_show = self.y[sampling_idx]
@@ -629,7 +628,7 @@ class BaseProject:
                         img = fig.add_subplot(rows, cols, idx)
                         if len(self.dims) > 2:
                             dims_imshow = rearrange_dims(self.dims, in_format=dataformats, dataformats="NHWC")
-                        img.imshow(self.X[sampling_idx][idx-1].ravel().reshape(dims_imshow))
+                        img.imshow(imgs_to_show[idx-1].reshape(dims_imshow))
                         img.set_title(f'label : {labels_to_show[idx-1]}')
             plt.show()
             plt.savefig(f"{img_dir}/image_samples.png")       
